#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-x509-system
version:              1.6.8
visibility:           public
id:                   crypton-x509-system-1.6.8-3H9C9ddlqygExAlZb9g5A
key:                  crypton-x509-system-1.6.8-3H9C9ddlqygExAlZb9g5A
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             Handle per-operating-system X.509 accessors and storage
description:
    System X.509 handling for accessing operating system dependents store and other storage methods

category:             Data
abi:                  5c10f8ac2e024f501aa34425a9b404ac
exposed:              True
exposed-modules:
    System.X509 System.X509.Common System.X509.MacOS System.X509.Unix

import-dirs:          /usr/lib/ghc-9.6.6/site-local/crypton-x509-system-1.6.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/crypton-x509-system-1.6.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/crypton-x509-system-1.6.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-system
hs-libraries:         HScrypton-x509-system-1.6.8-3H9C9ddlqygExAlZb9g5A
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    crypton-x509-1.7.7-7Cua3uCgisxCPoPehjYXxQ
    crypton-x509-store-1.6.12-CjJ4US6bbqi5cEtcJNu5Iv directory-1.3.8.5
    filepath-1.4.300.1 mtl-2.3.1 pem-0.2.4-H8vM6vSiioh2vevejgrSgd
    process-1.6.19.0

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-system/html/crypton-x509-system.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-system/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

